@@ -1,3 +1,3 @@
-SERIAL_PORT_STR = 'serial-port'
+SERIAL_PORT_STR = 'serial_port'
 BAUD_RATE_STR = 'baudrate'
 DEFAULT_BAUD_RATE = 38400
