@@ -47,7 +47,7 @@ def validate_checksum(packet_without_sync):
     is_valid = (ck_a == ck_a_ref and ck_b == ck_b_ref)
     if not is_valid:
         msg_str = helpers.print_bytes(packet_without_sync)
-        logger.debug('Invalid checksum for packet [ {} ] (nbytes {}), expected [ {} ], got [ {} ]'.format(msg_str, len(packet_without_sync), bytes([ck_a_ref, ck_b_ref]), bytes([ck_a, ck_b])))
+        logger.debug('Invalid checksum for packet [ {} ] (nbytes {}), expected [ {} ], got [ {} ]'.format(msg_str, len(packet_without_sync), bytes([ck_a_ref, ck_b_ref]), bytes([ck_a, ck_b])))
 
     return is_valid
 
@@ -136,7 +136,7 @@ def send(packet_type, payload, serial_stream):
 
     bytes_str = helpers.print_bytes(packet)
     n_bytes_written = serial_stream.write(packet)
-    logger.debug(f'Packet sent    [ {bytes_str} ], [ {n_bytes_written} ] bytes written')
+    logger.debug(f'Packet sent    [ {bytes_str} ], [ {n_bytes_written} ] bytes written')
     return n_bytes_written
 
 # -----
@@ -156,7 +156,7 @@ def send_hex_string(string, serial_stream):
     packet = struct.pack('<BB', *PREAMBLE) + msg + struct.pack('<BB', ck_a, ck_b)
     n_bytes_written = serial_stream.write(packet)
 
-    logger.debug(f'Packet sent    [ {helpers.print_bytes(packet)} ], [ {n_bytes_written} ] bytes written')
+    logger.debug(f'Packet sent    [ {helpers.print_bytes(packet)} ], [ {n_bytes_written} ] bytes written')
     return n_bytes_written
 
 # -----
@@ -238,16 +238,14 @@ def submit_valset_packet(key_value_dict, serial_stream, timeout=TIMEOUT_DEF):
 
     PACKET_TYPE = PacketType.CFG_VALSET
 
-    n_items_sent = 0
-
     sorted_dict = dict(sorted(key_value_dict.items(), key=lambda x : x[0].value))
-    for i,(key_id,value) in enumerate(sorted_dict.items()):
-        
-        #n_transaction = 2 if i else 1
-        n_transaction = 1
-        payload = struct.pack('<BBBB', 0, 7, n_transaction, 0)
 
-        logger.debug('submit_valset_packet::key_id [ {} ] --> [ {} ] (transaction {})'.format(key_id, value, n_transaction))
+    for key_id,value in sorted_dict.items():
+        
+        # Transaction-less submission of packets
+        payload = struct.pack('<BBBB', 0, 7, 0, 0)
+
+        logger.debug('submit_valset_packet::key_id [ {} ] --> [ {} ]'.format(key_id, value))
         try:
 
             payload += struct.pack('<L', key_id.value)
@@ -255,19 +253,12 @@ def submit_valset_packet(key_value_dict, serial_stream, timeout=TIMEOUT_DEF):
 
             payload += struct.pack(fmt, value)
         except Exception as e:
-            logger.warning(f'Error processing [ {key_id} ]: {str(e)}')
+            logger.warning(f'Error processing [ {key_id} ]: {str(e)}')
             continue
 
         send(PACKET_TYPE, payload, serial_stream)
         wait_for_ack_nak(PACKET_TYPE, serial_stream, timeout=TIMEOUT_DEF)
 
-        n_items_sent += 1
-
-    if n_items_sent:
-        payload = struct.pack('<BBBB', 1, 7, 3, 0)
-        send(PACKET_TYPE, payload, serial_stream)
-        wait_for_ack_nak(PACKET_TYPE, serial_stream, timeout=TIMEOUT_DEF)
-
     logger.info('Ending transaction for VALSET!')
 
 
